Class: Aws::ServiceCatalog::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ServiceCatalog::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-servicecatalog/client.rb,
sig/client.rbs
Overview
An API client for ServiceCatalog. To construct a client, you need to configure a :region and :credentials.
client = Aws::ServiceCatalog::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptPortfolioShareResponseSuccess, _AssociateBudgetWithResourceResponseSuccess, _AssociatePrincipalWithPortfolioResponseSuccess, _AssociateProductWithPortfolioResponseSuccess, _AssociateServiceActionWithProvisioningArtifactResponseSuccess, _AssociateTagOptionWithResourceResponseSuccess, _BatchAssociateServiceActionWithProvisioningArtifactResponseSuccess, _BatchDisassociateServiceActionFromProvisioningArtifactResponseSuccess, _CopyProductResponseSuccess, _CreateConstraintResponseSuccess, _CreatePortfolioResponseSuccess, _CreatePortfolioShareResponseSuccess, _CreateProductResponseSuccess, _CreateProvisionedProductPlanResponseSuccess, _CreateProvisioningArtifactResponseSuccess, _CreateServiceActionResponseSuccess, _CreateTagOptionResponseSuccess, _DeleteConstraintResponseSuccess, _DeletePortfolioResponseSuccess, _DeletePortfolioShareResponseSuccess, _DeleteProductResponseSuccess, _DeleteProvisionedProductPlanResponseSuccess, _DeleteProvisioningArtifactResponseSuccess, _DeleteServiceActionResponseSuccess, _DeleteTagOptionResponseSuccess, _DescribeConstraintResponseSuccess, _DescribeCopyProductStatusResponseSuccess, _DescribePortfolioResponseSuccess, _DescribePortfolioShareStatusResponseSuccess, _DescribePortfolioSharesResponseSuccess, _DescribeProductAsAdminResponseSuccess, _DescribeProductResponseSuccess, _DescribeProductViewResponseSuccess, _DescribeProvisionedProductPlanResponseSuccess, _DescribeProvisionedProductResponseSuccess, _DescribeProvisioningArtifactResponseSuccess, _DescribeProvisioningParametersResponseSuccess, _DescribeRecordResponseSuccess, _DescribeServiceActionExecutionParametersResponseSuccess, _DescribeServiceActionResponseSuccess, _DescribeTagOptionResponseSuccess, _DisableAWSOrganizationsAccessResponseSuccess, _DisassociateBudgetFromResourceResponseSuccess, _DisassociatePrincipalFromPortfolioResponseSuccess, _DisassociateProductFromPortfolioResponseSuccess, _DisassociateServiceActionFromProvisioningArtifactResponseSuccess, _DisassociateTagOptionFromResourceResponseSuccess, _EnableAWSOrganizationsAccessResponseSuccess, _ExecuteProvisionedProductPlanResponseSuccess, _ExecuteProvisionedProductServiceActionResponseSuccess, _GetAWSOrganizationsAccessStatusResponseSuccess, _GetProvisionedProductOutputsResponseSuccess, _ImportAsProvisionedProductResponseSuccess, _ListAcceptedPortfolioSharesResponseSuccess, _ListBudgetsForResourceResponseSuccess, _ListConstraintsForPortfolioResponseSuccess, _ListLaunchPathsResponseSuccess, _ListOrganizationPortfolioAccessResponseSuccess, _ListPortfolioAccessResponseSuccess, _ListPortfoliosForProductResponseSuccess, _ListPortfoliosResponseSuccess, _ListPrincipalsForPortfolioResponseSuccess, _ListProvisionedProductPlansResponseSuccess, _ListProvisioningArtifactsForServiceActionResponseSuccess, _ListProvisioningArtifactsResponseSuccess, _ListRecordHistoryResponseSuccess, _ListResourcesForTagOptionResponseSuccess, _ListServiceActionsForProvisioningArtifactResponseSuccess, _ListServiceActionsResponseSuccess, _ListStackInstancesForProvisionedProductResponseSuccess, _ListTagOptionsResponseSuccess, _NotifyProvisionProductEngineWorkflowResultResponseSuccess, _NotifyTerminateProvisionedProductEngineWorkflowResultResponseSuccess, _NotifyUpdateProvisionedProductEngineWorkflowResultResponseSuccess, _ProvisionProductResponseSuccess, _RejectPortfolioShareResponseSuccess, _ScanProvisionedProductsResponseSuccess, _SearchProductsAsAdminResponseSuccess, _SearchProductsResponseSuccess, _SearchProvisionedProductsResponseSuccess, _TerminateProvisionedProductResponseSuccess, _UpdateConstraintResponseSuccess, _UpdatePortfolioResponseSuccess, _UpdatePortfolioShareResponseSuccess, _UpdateProductResponseSuccess, _UpdateProvisionedProductPropertiesResponseSuccess, _UpdateProvisionedProductResponseSuccess, _UpdateProvisioningArtifactResponseSuccess, _UpdateServiceActionResponseSuccess, _UpdateTagOptionResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_portfolio_share(params = {}) ⇒ Struct
Accepts an offer to share the specified portfolio.
-
#associate_budget_with_resource(params = {}) ⇒ Struct
Associates the specified budget with the specified resource.
-
#associate_principal_with_portfolio(params = {}) ⇒ Struct
Associates the specified principal ARN with the specified portfolio.
-
#associate_product_with_portfolio(params = {}) ⇒ Struct
Associates the specified product with the specified portfolio.
-
#associate_service_action_with_provisioning_artifact(params = {}) ⇒ Struct
Associates a self-service action with a provisioning artifact.
-
#associate_tag_option_with_resource(params = {}) ⇒ Struct
Associate the specified TagOption with the specified portfolio or product.
-
#batch_associate_service_action_with_provisioning_artifact(params = {}) ⇒ Types::BatchAssociateServiceActionWithProvisioningArtifactOutput
Associates multiple self-service actions with provisioning artifacts.
-
#batch_disassociate_service_action_from_provisioning_artifact(params = {}) ⇒ Types::BatchDisassociateServiceActionFromProvisioningArtifactOutput
Disassociates a batch of self-service actions from the specified provisioning artifact.
-
#copy_product(params = {}) ⇒ Types::CopyProductOutput
Copies the specified source product to the specified target product or a new product.
-
#create_constraint(params = {}) ⇒ Types::CreateConstraintOutput
Creates a constraint.
-
#create_portfolio(params = {}) ⇒ Types::CreatePortfolioOutput
Creates a portfolio.
-
#create_portfolio_share(params = {}) ⇒ Types::CreatePortfolioShareOutput
Shares the specified portfolio with the specified account or organization node.
-
#create_product(params = {}) ⇒ Types::CreateProductOutput
Creates a product.
-
#create_provisioned_product_plan(params = {}) ⇒ Types::CreateProvisionedProductPlanOutput
Creates a plan.
-
#create_provisioning_artifact(params = {}) ⇒ Types::CreateProvisioningArtifactOutput
Creates a provisioning artifact (also known as a version) for the specified product.
-
#create_service_action(params = {}) ⇒ Types::CreateServiceActionOutput
Creates a self-service action.
-
#create_tag_option(params = {}) ⇒ Types::CreateTagOptionOutput
Creates a TagOption.
-
#delete_constraint(params = {}) ⇒ Struct
Deletes the specified constraint.
-
#delete_portfolio(params = {}) ⇒ Struct
Deletes the specified portfolio.
-
#delete_portfolio_share(params = {}) ⇒ Types::DeletePortfolioShareOutput
Stops sharing the specified portfolio with the specified account or organization node.
-
#delete_product(params = {}) ⇒ Struct
Deletes the specified product.
-
#delete_provisioned_product_plan(params = {}) ⇒ Struct
Deletes the specified plan.
-
#delete_provisioning_artifact(params = {}) ⇒ Struct
Deletes the specified provisioning artifact (also known as a version) for the specified product.
-
#delete_service_action(params = {}) ⇒ Struct
Deletes a self-service action.
-
#delete_tag_option(params = {}) ⇒ Struct
Deletes the specified TagOption.
-
#describe_constraint(params = {}) ⇒ Types::DescribeConstraintOutput
Gets information about the specified constraint.
-
#describe_copy_product_status(params = {}) ⇒ Types::DescribeCopyProductStatusOutput
Gets the status of the specified copy product operation.
-
#describe_portfolio(params = {}) ⇒ Types::DescribePortfolioOutput
Gets information about the specified portfolio.
-
#describe_portfolio_share_status(params = {}) ⇒ Types::DescribePortfolioShareStatusOutput
Gets the status of the specified portfolio share operation.
-
#describe_portfolio_shares(params = {}) ⇒ Types::DescribePortfolioSharesOutput
Returns a summary of each of the portfolio shares that were created for the specified portfolio.
-
#describe_product(params = {}) ⇒ Types::DescribeProductOutput
Gets information about the specified product.
-
#describe_product_as_admin(params = {}) ⇒ Types::DescribeProductAsAdminOutput
Gets information about the specified product.
-
#describe_product_view(params = {}) ⇒ Types::DescribeProductViewOutput
Gets information about the specified product.
-
#describe_provisioned_product(params = {}) ⇒ Types::DescribeProvisionedProductOutput
Gets information about the specified provisioned product.
-
#describe_provisioned_product_plan(params = {}) ⇒ Types::DescribeProvisionedProductPlanOutput
Gets information about the resource changes for the specified plan.
-
#describe_provisioning_artifact(params = {}) ⇒ Types::DescribeProvisioningArtifactOutput
Gets information about the specified provisioning artifact (also known as a version) for the specified product.
-
#describe_provisioning_parameters(params = {}) ⇒ Types::DescribeProvisioningParametersOutput
Gets information about the configuration required to provision the specified product using the specified provisioning artifact.
-
#describe_record(params = {}) ⇒ Types::DescribeRecordOutput
Gets information about the specified request operation.
-
#describe_service_action(params = {}) ⇒ Types::DescribeServiceActionOutput
Describes a self-service action.
-
#describe_service_action_execution_parameters(params = {}) ⇒ Types::DescribeServiceActionExecutionParametersOutput
Finds the default parameters for a specific self-service action on a specific provisioned product and returns a map of the results to the user.
-
#describe_tag_option(params = {}) ⇒ Types::DescribeTagOptionOutput
Gets information about the specified TagOption.
-
#disable_aws_organizations_access(params = {}) ⇒ Struct
Disable portfolio sharing through the Organizations service.
-
#disassociate_budget_from_resource(params = {}) ⇒ Struct
Disassociates the specified budget from the specified resource.
-
#disassociate_principal_from_portfolio(params = {}) ⇒ Struct
Disassociates a previously associated principal ARN from a specified portfolio.
-
#disassociate_product_from_portfolio(params = {}) ⇒ Struct
Disassociates the specified product from the specified portfolio.
-
#disassociate_service_action_from_provisioning_artifact(params = {}) ⇒ Struct
Disassociates the specified self-service action association from the specified provisioning artifact.
-
#disassociate_tag_option_from_resource(params = {}) ⇒ Struct
Disassociates the specified TagOption from the specified resource.
-
#enable_aws_organizations_access(params = {}) ⇒ Struct
Enable portfolio sharing feature through Organizations.
-
#execute_provisioned_product_plan(params = {}) ⇒ Types::ExecuteProvisionedProductPlanOutput
Provisions or modifies a product based on the resource changes for the specified plan.
-
#execute_provisioned_product_service_action(params = {}) ⇒ Types::ExecuteProvisionedProductServiceActionOutput
Executes a self-service action against a provisioned product.
-
#get_aws_organizations_access_status(params = {}) ⇒ Types::GetAWSOrganizationsAccessStatusOutput
Get the Access Status for Organizations portfolio share feature.
-
#get_provisioned_product_outputs(params = {}) ⇒ Types::GetProvisionedProductOutputsOutput
This API takes either a
ProvisonedProductIdor aProvisionedProductName, along with a list of one or more output keys, and responds with the key/value pairs of those outputs. -
#import_as_provisioned_product(params = {}) ⇒ Types::ImportAsProvisionedProductOutput
Requests the import of a resource as an Service Catalog provisioned product that is associated to an Service Catalog product and provisioning artifact.
-
#list_accepted_portfolio_shares(params = {}) ⇒ Types::ListAcceptedPortfolioSharesOutput
Lists all imported portfolios for which account-to-account shares were accepted by this account.
-
#list_budgets_for_resource(params = {}) ⇒ Types::ListBudgetsForResourceOutput
Lists all the budgets associated to the specified resource.
-
#list_constraints_for_portfolio(params = {}) ⇒ Types::ListConstraintsForPortfolioOutput
Lists the constraints for the specified portfolio and product.
-
#list_launch_paths(params = {}) ⇒ Types::ListLaunchPathsOutput
Lists the paths to the specified product.
-
#list_organization_portfolio_access(params = {}) ⇒ Types::ListOrganizationPortfolioAccessOutput
Lists the organization nodes that have access to the specified portfolio.
-
#list_portfolio_access(params = {}) ⇒ Types::ListPortfolioAccessOutput
Lists the account IDs that have access to the specified portfolio.
-
#list_portfolios(params = {}) ⇒ Types::ListPortfoliosOutput
Lists all portfolios in the catalog.
-
#list_portfolios_for_product(params = {}) ⇒ Types::ListPortfoliosForProductOutput
Lists all portfolios that the specified product is associated with.
-
#list_principals_for_portfolio(params = {}) ⇒ Types::ListPrincipalsForPortfolioOutput
Lists all
PrincipalARNs and correspondingPrincipalTypes associated with the specified portfolio. -
#list_provisioned_product_plans(params = {}) ⇒ Types::ListProvisionedProductPlansOutput
Lists the plans for the specified provisioned product or all plans to which the user has access.
-
#list_provisioning_artifacts(params = {}) ⇒ Types::ListProvisioningArtifactsOutput
Lists all provisioning artifacts (also known as versions) for the specified product.
-
#list_provisioning_artifacts_for_service_action(params = {}) ⇒ Types::ListProvisioningArtifactsForServiceActionOutput
Lists all provisioning artifacts (also known as versions) for the specified self-service action.
-
#list_record_history(params = {}) ⇒ Types::ListRecordHistoryOutput
Lists the specified requests or all performed requests.
-
#list_resources_for_tag_option(params = {}) ⇒ Types::ListResourcesForTagOptionOutput
Lists the resources associated with the specified TagOption.
-
#list_service_actions(params = {}) ⇒ Types::ListServiceActionsOutput
Lists all self-service actions.
-
#list_service_actions_for_provisioning_artifact(params = {}) ⇒ Types::ListServiceActionsForProvisioningArtifactOutput
Returns a paginated list of self-service actions associated with the specified Product ID and Provisioning Artifact ID.
-
#list_stack_instances_for_provisioned_product(params = {}) ⇒ Types::ListStackInstancesForProvisionedProductOutput
Returns summary information about stack instances that are associated with the specified
CFN_STACKSETtype provisioned product. -
#list_tag_options(params = {}) ⇒ Types::ListTagOptionsOutput
Lists the specified TagOptions or all TagOptions.
-
#notify_provision_product_engine_workflow_result(params = {}) ⇒ Struct
Notifies the result of the provisioning engine execution.
-
#notify_terminate_provisioned_product_engine_workflow_result(params = {}) ⇒ Struct
Notifies the result of the terminate engine execution.
-
#notify_update_provisioned_product_engine_workflow_result(params = {}) ⇒ Struct
Notifies the result of the update engine execution.
-
#provision_product(params = {}) ⇒ Types::ProvisionProductOutput
Provisions the specified product.
-
#reject_portfolio_share(params = {}) ⇒ Struct
Rejects an offer to share the specified portfolio.
-
#scan_provisioned_products(params = {}) ⇒ Types::ScanProvisionedProductsOutput
Lists the provisioned products that are available (not terminated).
-
#search_products(params = {}) ⇒ Types::SearchProductsOutput
Gets information about the products to which the caller has access.
-
#search_products_as_admin(params = {}) ⇒ Types::SearchProductsAsAdminOutput
Gets information about the products for the specified portfolio or all products.
-
#search_provisioned_products(params = {}) ⇒ Types::SearchProvisionedProductsOutput
Gets information about the provisioned products that meet the specified criteria.
-
#terminate_provisioned_product(params = {}) ⇒ Types::TerminateProvisionedProductOutput
Terminates the specified provisioned product.
-
#update_constraint(params = {}) ⇒ Types::UpdateConstraintOutput
Updates the specified constraint.
-
#update_portfolio(params = {}) ⇒ Types::UpdatePortfolioOutput
Updates the specified portfolio.
-
#update_portfolio_share(params = {}) ⇒ Types::UpdatePortfolioShareOutput
Updates the specified portfolio share.
-
#update_product(params = {}) ⇒ Types::UpdateProductOutput
Updates the specified product.
-
#update_provisioned_product(params = {}) ⇒ Types::UpdateProvisionedProductOutput
Requests updates to the configuration of the specified provisioned product.
-
#update_provisioned_product_properties(params = {}) ⇒ Types::UpdateProvisionedProductPropertiesOutput
Requests updates to the properties of the specified provisioned product.
-
#update_provisioning_artifact(params = {}) ⇒ Types::UpdateProvisioningArtifactOutput
Updates the specified provisioning artifact (also known as a version) for the specified product.
-
#update_service_action(params = {}) ⇒ Types::UpdateServiceActionOutput
Updates a self-service action.
-
#update_tag_option(params = {}) ⇒ Types::UpdateTagOptionOutput
Updates the specified TagOption.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-servicecatalog/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6393 6394 6395 |
# File 'lib/aws-sdk-servicecatalog/client.rb', line 6393 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6396 6397 6398 |
# File 'lib/aws-sdk-servicecatalog/client.rb', line 6396 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_portfolio_share(params = {}) ⇒ Struct
Accepts an offer to share the specified portfolio.
86 |
# File 'sig/client.rbs', line 86
def accept_portfolio_share: (
|
#associate_budget_with_resource(params = {}) ⇒ Struct
Associates the specified budget with the specified resource.
97 |
# File 'sig/client.rbs', line 97
def associate_budget_with_resource: (
|
#associate_principal_with_portfolio(params = {}) ⇒ Struct
Associates the specified principal ARN with the specified portfolio.
If you share the portfolio with principal name sharing enabled, the
PrincipalARN association is included in the share.
The PortfolioID, PrincipalARN, and PrincipalType parameters are
required.
You can associate a maximum of 10 Principals with a portfolio using
PrincipalType as IAM_PATTERN.
PrincipalType as
IAM. With this configuration, the PrincipalARN must already exist
in the recipient account before it can be associated.
107 |
# File 'sig/client.rbs', line 107
def associate_principal_with_portfolio: (
|
#associate_product_with_portfolio(params = {}) ⇒ Struct
Associates the specified product with the specified portfolio.
A delegated admin is authorized to invoke this command.
119 |
# File 'sig/client.rbs', line 119
def associate_product_with_portfolio: (
|
#associate_service_action_with_provisioning_artifact(params = {}) ⇒ Struct
Associates a self-service action with a provisioning artifact.
131 |
# File 'sig/client.rbs', line 131
def associate_service_action_with_provisioning_artifact: (
|
#associate_tag_option_with_resource(params = {}) ⇒ Struct
Associate the specified TagOption with the specified portfolio or product.
144 |
# File 'sig/client.rbs', line 144
def associate_tag_option_with_resource: (
|
#batch_associate_service_action_with_provisioning_artifact(params = {}) ⇒ Types::BatchAssociateServiceActionWithProvisioningArtifactOutput
Associates multiple self-service actions with provisioning artifacts.
155 |
# File 'sig/client.rbs', line 155
def batch_associate_service_action_with_provisioning_artifact: (
|
#batch_disassociate_service_action_from_provisioning_artifact(params = {}) ⇒ Types::BatchDisassociateServiceActionFromProvisioningArtifactOutput
Disassociates a batch of self-service actions from the specified provisioning artifact.
172 |
# File 'sig/client.rbs', line 172
def batch_disassociate_service_action_from_provisioning_artifact: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6366 6367 6368 6369 6370 6371 6372 6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 |
# File 'lib/aws-sdk-servicecatalog/client.rb', line 6366 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ServiceCatalog') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-servicecatalog' context[:gem_version] = '1.132.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_product(params = {}) ⇒ Types::CopyProductOutput
Copies the specified source product to the specified target product or a new product.
You can copy a product to the same account or another account. You can copy a product to the same Region or another Region. If you copy a product to another account, you must first share the product in a portfolio using CreatePortfolioShare.
This operation is performed asynchronously. To track the progress of the operation, use DescribeCopyProductStatus.
189 |
# File 'sig/client.rbs', line 189
def copy_product: (
|
#create_constraint(params = {}) ⇒ Types::CreateConstraintOutput
Creates a constraint.
A delegated admin is authorized to invoke this command.
209 |
# File 'sig/client.rbs', line 209
def create_constraint: (
|
#create_portfolio(params = {}) ⇒ Types::CreatePortfolioOutput
Creates a portfolio.
A delegated admin is authorized to invoke this command.
226 |
# File 'sig/client.rbs', line 226
def create_portfolio: (
|
#create_portfolio_share(params = {}) ⇒ Types::CreatePortfolioShareOutput
Shares the specified portfolio with the specified account or organization node. Shares to an organization node can only be created by the management account of an organization or by a delegated administrator. You can share portfolios to an organization, an organizational unit, or a specific account.
Note that if a delegated admin is de-registered, they can no longer create portfolio shares.
AWSOrganizationsAccess must be enabled in order to create a
portfolio share to an organization node.
You can't share a shared resource, including portfolios that contain a shared product.
If the portfolio share with the specified account or organization node
already exists, this action will have no effect and will not return an
error. To update an existing share, you must use the UpdatePortfolioShare API instead.
PrincipalType as
IAM. With this configuration, the PrincipalARN must already exist
in the recipient account before it can be associated.
246 |
# File 'sig/client.rbs', line 246
def create_portfolio_share: (
|
#create_product(params = {}) ⇒ Types::CreateProductOutput
Creates a product.
A delegated admin is authorized to invoke this command.
The user or role that performs this operation must have the
cloudformation:GetTemplate IAM policy permission. This policy
permission is required when using the ImportFromPhysicalId template
source in the information data section.
266 |
# File 'sig/client.rbs', line 266
def create_product: (
|
#create_provisioned_product_plan(params = {}) ⇒ Types::CreateProvisionedProductPlanOutput
Creates a plan.
A plan includes the list of resources to be created (when provisioning a new product) or modified (when updating a provisioned product) when the plan is executed.
You can create one plan for each provisioned product. To create a plan for an existing provisioned product, the product status must be AVAILABLE or TAINTED.
To view the resource changes in the change set, use DescribeProvisionedProductPlan. To create or modify the provisioned product, use ExecuteProvisionedProductPlan.
303 |
# File 'sig/client.rbs', line 303
def create_provisioned_product_plan: (
|
#create_provisioning_artifact(params = {}) ⇒ Types::CreateProvisioningArtifactOutput
Creates a provisioning artifact (also known as a version) for the specified product.
You cannot create a provisioning artifact for a product that was shared with you.
The user or role that performs this operation must have the
cloudformation:GetTemplate IAM policy permission. This policy
permission is required when using the ImportFromPhysicalId template
source in the information data section.
336 |
# File 'sig/client.rbs', line 336
def create_provisioning_artifact: (
|
#create_service_action(params = {}) ⇒ Types::CreateServiceActionOutput
Creates a self-service action.
355 |
# File 'sig/client.rbs', line 355
def create_service_action: (
|
#create_tag_option(params = {}) ⇒ Types::CreateTagOptionOutput
Creates a TagOption.
370 |
# File 'sig/client.rbs', line 370
def create_tag_option: (
|
#delete_constraint(params = {}) ⇒ Struct
Deletes the specified constraint.
A delegated admin is authorized to invoke this command.
380 |
# File 'sig/client.rbs', line 380
def delete_constraint: (
|
#delete_portfolio(params = {}) ⇒ Struct
Deletes the specified portfolio.
You cannot delete a portfolio if it was shared with you or if it has associated products, users, constraints, or shared accounts.
A delegated admin is authorized to invoke this command.
390 |
# File 'sig/client.rbs', line 390
def delete_portfolio: (
|
#delete_portfolio_share(params = {}) ⇒ Types::DeletePortfolioShareOutput
Stops sharing the specified portfolio with the specified account or organization node. Shares to an organization node can only be deleted by the management account of an organization or by a delegated administrator.
Note that if a delegated admin is de-registered, portfolio shares created from that account are removed.
401 |
# File 'sig/client.rbs', line 401
def delete_portfolio_share: (
|
#delete_product(params = {}) ⇒ Struct
Deletes the specified product.
You cannot delete a product if it was shared with you or is associated with a portfolio.
A delegated admin is authorized to invoke this command.
416 |
# File 'sig/client.rbs', line 416
def delete_product: (
|
#delete_provisioned_product_plan(params = {}) ⇒ Struct
Deletes the specified plan.
426 |
# File 'sig/client.rbs', line 426
def delete_provisioned_product_plan: (
|
#delete_provisioning_artifact(params = {}) ⇒ Struct
Deletes the specified provisioning artifact (also known as a version) for the specified product.
You cannot delete a provisioning artifact associated with a product that was shared with you. You cannot delete the last provisioning artifact for a product, because a product must have at least one provisioning artifact.
437 |
# File 'sig/client.rbs', line 437
def delete_provisioning_artifact: (
|
#delete_service_action(params = {}) ⇒ Struct
Deletes a self-service action.
448 |
# File 'sig/client.rbs', line 448
def delete_service_action: (
|
#delete_tag_option(params = {}) ⇒ Struct
Deletes the specified TagOption.
You cannot delete a TagOption if it is associated with a product or portfolio.
459 |
# File 'sig/client.rbs', line 459
def delete_tag_option: (
|
#describe_constraint(params = {}) ⇒ Types::DescribeConstraintOutput
Gets information about the specified constraint.
471 |
# File 'sig/client.rbs', line 471
def describe_constraint: (
|
#describe_copy_product_status(params = {}) ⇒ Types::DescribeCopyProductStatusOutput
Gets the status of the specified copy product operation.
484 |
# File 'sig/client.rbs', line 484
def describe_copy_product_status: (
|
#describe_portfolio(params = {}) ⇒ Types::DescribePortfolioOutput
Gets information about the specified portfolio.
A delegated admin is authorized to invoke this command.
498 |
# File 'sig/client.rbs', line 498
def describe_portfolio: (
|
#describe_portfolio_share_status(params = {}) ⇒ Types::DescribePortfolioShareStatusOutput
Gets the status of the specified portfolio share operation. This API can only be called by the management account in the organization or by a delegated admin.
513 |
# File 'sig/client.rbs', line 513
def describe_portfolio_share_status: (
|
#describe_portfolio_shares(params = {}) ⇒ Types::DescribePortfolioSharesOutput
Returns a summary of each of the portfolio shares that were created for the specified portfolio.
You can use this API to determine which accounts or organizational nodes this portfolio have been shared, whether the recipient entity has imported the share, and whether TagOptions are included with the share.
The PortfolioId and Type parameters are both required.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
524 |
# File 'sig/client.rbs', line 524
def describe_portfolio_shares: (
|
#describe_product(params = {}) ⇒ Types::DescribeProductOutput
Gets information about the specified product.
540 |
# File 'sig/client.rbs', line 540
def describe_product: (
|
#describe_product_as_admin(params = {}) ⇒ Types::DescribeProductAsAdminOutput
Gets information about the specified product. This operation is run with administrator access.
556 |
# File 'sig/client.rbs', line 556
def describe_product_as_admin: (
|
#describe_product_view(params = {}) ⇒ Types::DescribeProductViewOutput
Gets information about the specified product.
570 |
# File 'sig/client.rbs', line 570
def describe_product_view: (
|
#describe_provisioned_product(params = {}) ⇒ Types::DescribeProvisionedProductOutput
Gets information about the specified provisioned product.
582 |
# File 'sig/client.rbs', line 582
def describe_provisioned_product: (
|
#describe_provisioned_product_plan(params = {}) ⇒ Types::DescribeProvisionedProductPlanOutput
Gets information about the resource changes for the specified plan.
596 |
# File 'sig/client.rbs', line 596
def describe_provisioned_product_plan: (
|
#describe_provisioning_artifact(params = {}) ⇒ Types::DescribeProvisioningArtifactOutput
Gets information about the specified provisioning artifact (also known as a version) for the specified product.
612 |
# File 'sig/client.rbs', line 612
def describe_provisioning_artifact: (
|
#describe_provisioning_parameters(params = {}) ⇒ Types::DescribeProvisioningParametersOutput
Gets information about the configuration required to provision the specified product using the specified provisioning artifact.
If the output contains a TagOption key with an empty list of values,
there is a TagOption conflict for that key. The end user cannot take
action to fix the conflict, and launch is not blocked. In subsequent
calls to ProvisionProduct, do not include conflicted TagOption keys as
tags, or this causes the error "Parameter validation failed: Missing
required parameter in Tags[N]:Value". Tag the provisioned
product with the value sc-tagoption-conflict-portfolioId-productId.
634 |
# File 'sig/client.rbs', line 634
def describe_provisioning_parameters: (
|
#describe_record(params = {}) ⇒ Types::DescribeRecordOutput
Gets information about the specified request operation.
Use this operation after calling a request operation (for example, ProvisionProduct, TerminateProvisionedProduct, or UpdateProvisionedProduct).
652 |
# File 'sig/client.rbs', line 652
def describe_record: (
|
#describe_service_action(params = {}) ⇒ Types::DescribeServiceActionOutput
Describes a self-service action.
665 |
# File 'sig/client.rbs', line 665
def describe_service_action: (
|
#describe_service_action_execution_parameters(params = {}) ⇒ Types::DescribeServiceActionExecutionParametersOutput
Finds the default parameters for a specific self-service action on a specific provisioned product and returns a map of the results to the user.
676 |
# File 'sig/client.rbs', line 676
def describe_service_action_execution_parameters: (
|
#describe_tag_option(params = {}) ⇒ Types::DescribeTagOptionOutput
Gets information about the specified TagOption.
688 |
# File 'sig/client.rbs', line 688
def describe_tag_option: (
|
#disable_aws_organizations_access(params = {}) ⇒ Struct
Disable portfolio sharing through the Organizations service. This command will not delete your current shares, but prevents you from creating new shares throughout your organization. Current shares are not kept in sync with your organization structure if the structure changes after calling this API. Only the management account in the organization can call this API.
You cannot call this API if there are active delegated administrators in the organization.
Note that a delegated administrator is not authorized to invoke
DisableAWSOrganizationsAccess.
If you share an Service Catalog portfolio in an organization within Organizations, and then disable Organizations access for Service Catalog, the portfolio access permissions will not sync with the latest changes to the organization structure. Specifically, accounts that you removed from the organization after disabling Service Catalog access will retain access to the previously shared portfolio.
697 |
# File 'sig/client.rbs', line 697
def disable_aws_organizations_access: (
|
#disassociate_budget_from_resource(params = {}) ⇒ Struct
Disassociates the specified budget from the specified resource.
705 |
# File 'sig/client.rbs', line 705
def disassociate_budget_from_resource: (
|
#disassociate_principal_from_portfolio(params = {}) ⇒ Struct
Disassociates a previously associated principal ARN from a specified portfolio.
The PrincipalType and PrincipalARN must match the
AssociatePrincipalWithPortfolio call request details. For example,
to disassociate an association created with a PrincipalARN of
PrincipalType IAM you must use the PrincipalType IAM when calling
DisassociatePrincipalFromPortfolio.
For portfolios that have been shared with principal name sharing enabled: after disassociating a principal, share recipient accounts will no longer be able to provision products in this portfolio using a role matching the name of the associated principal.
For more information, review associate-principal-with-portfolio in the Amazon Web Services CLI Command Reference.
IAM, the same principal will still have access to the portfolio
if it matches one of the associated principals of type IAM_PATTERN.
To fully remove access for a principal, verify all the associated
Principals of type IAM_PATTERN, and then ensure you disassociate any
IAM_PATTERN principals that match the principal whose access you are
removing.
715 |
# File 'sig/client.rbs', line 715
def disassociate_principal_from_portfolio: (
|
#disassociate_product_from_portfolio(params = {}) ⇒ Struct
Disassociates the specified product from the specified portfolio.
A delegated admin is authorized to invoke this command.
727 |
# File 'sig/client.rbs', line 727
def disassociate_product_from_portfolio: (
|
#disassociate_service_action_from_provisioning_artifact(params = {}) ⇒ Struct
Disassociates the specified self-service action association from the specified provisioning artifact.
738 |
# File 'sig/client.rbs', line 738
def disassociate_service_action_from_provisioning_artifact: (
|
#disassociate_tag_option_from_resource(params = {}) ⇒ Struct
Disassociates the specified TagOption from the specified resource.
751 |
# File 'sig/client.rbs', line 751
def disassociate_tag_option_from_resource: (
|
#enable_aws_organizations_access(params = {}) ⇒ Struct
Enable portfolio sharing feature through Organizations. This API will allow Service Catalog to receive updates on your organization in order to sync your shares with the current structure. This API can only be called by the management account in the organization.
When you call this API, Service Catalog calls
organizations:EnableAWSServiceAccess on your behalf so that your
shares stay in sync with any changes in your Organizations structure.
Note that a delegated administrator is not authorized to invoke
EnableAWSOrganizationsAccess.
If you have previously disabled Organizations access for Service Catalog, and then enable access again, the portfolio access permissions might not sync with the latest changes to the organization structure. Specifically, accounts that you removed from the organization after disabling Service Catalog access, and before you enabled access again, can retain access to the previously shared portfolio. As a result, an account that has been removed from the organization might still be able to create or manage Amazon Web Services resources when it is no longer authorized to do so. Amazon Web Services is working to resolve this issue.
761 |
# File 'sig/client.rbs', line 761
def enable_aws_organizations_access: (
|
#execute_provisioned_product_plan(params = {}) ⇒ Types::ExecuteProvisionedProductPlanOutput
Provisions or modifies a product based on the resource changes for the specified plan.
770 |
# File 'sig/client.rbs', line 770
def execute_provisioned_product_plan: (
|
#execute_provisioned_product_service_action(params = {}) ⇒ Types::ExecuteProvisionedProductServiceActionOutput
Executes a self-service action against a provisioned product.
782 |
# File 'sig/client.rbs', line 782
def execute_provisioned_product_service_action: (
|
#get_aws_organizations_access_status(params = {}) ⇒ Types::GetAWSOrganizationsAccessStatusOutput
Get the Access Status for Organizations portfolio share feature. This API can only be called by the management account in the organization or by a delegated admin.
796 |
# File 'sig/client.rbs', line 796
def get_aws_organizations_access_status: (
|
#get_provisioned_product_outputs(params = {}) ⇒ Types::GetProvisionedProductOutputsOutput
This API takes either a ProvisonedProductId or a
ProvisionedProductName, along with a list of one or more output
keys, and responds with the key/value pairs of those outputs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
806 |
# File 'sig/client.rbs', line 806
def get_provisioned_product_outputs: (
|
#import_as_provisioned_product(params = {}) ⇒ Types::ImportAsProvisionedProductOutput
Requests the import of a resource as an Service Catalog provisioned product that is associated to an Service Catalog product and provisioning artifact. Once imported, all supported governance actions are supported on the provisioned product.
Resource import only supports CloudFormation stack ARNs. CloudFormation StackSets, and non-root nested stacks, are not supported.
The CloudFormation stack must have one of the following statuses to be
imported: CREATE_COMPLETE, UPDATE_COMPLETE,
UPDATE_ROLLBACK_COMPLETE, IMPORT_COMPLETE, and
IMPORT_ROLLBACK_COMPLETE.
Import of the resource requires that the CloudFormation stack template matches the associated Service Catalog product provisioning artifact.
UpdateProvisionedProduct for the provisioned product.
The user or role that performs this operation must have the
cloudformation:GetTemplate and cloudformation:DescribeStacks IAM
policy permissions.
You can only import one provisioned product at a time. The product's
CloudFormation stack must have the IMPORT_COMPLETE status before you
import another.
821 |
# File 'sig/client.rbs', line 821
def import_as_provisioned_product: (
|
#list_accepted_portfolio_shares(params = {}) ⇒ Types::ListAcceptedPortfolioSharesOutput
Lists all imported portfolios for which account-to-account shares were
accepted by this account. By specifying the PortfolioShareType, you
can list portfolios for which organizational shares were accepted by
this account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
837 |
# File 'sig/client.rbs', line 837
def list_accepted_portfolio_shares: (
|
#list_budgets_for_resource(params = {}) ⇒ Types::ListBudgetsForResourceOutput
Lists all the budgets associated to the specified resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
851 |
# File 'sig/client.rbs', line 851
def list_budgets_for_resource: (
|
#list_constraints_for_portfolio(params = {}) ⇒ Types::ListConstraintsForPortfolioOutput
Lists the constraints for the specified portfolio and product.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
865 |
# File 'sig/client.rbs', line 865
def list_constraints_for_portfolio: (
|
#list_launch_paths(params = {}) ⇒ Types::ListLaunchPathsOutput
Lists the paths to the specified product. A path describes how the user gets access to a specified product and is necessary when provisioning a product. A path also determines the constraints that are put on a product. A path is dependent on a specific product, porfolio, and principal.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
880 |
# File 'sig/client.rbs', line 880
def list_launch_paths: (
|
#list_organization_portfolio_access(params = {}) ⇒ Types::ListOrganizationPortfolioAccessOutput
Lists the organization nodes that have access to the specified portfolio. This API can only be called by the management account in the organization or by a delegated admin.
If a delegated admin is de-registered, they can no longer perform this operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
894 |
# File 'sig/client.rbs', line 894
def list_organization_portfolio_access: (
|
#list_portfolio_access(params = {}) ⇒ Types::ListPortfolioAccessOutput
Lists the account IDs that have access to the specified portfolio.
A delegated admin can list the accounts that have access to the shared portfolio. Note that if a delegated admin is de-registered, they can no longer perform this operation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
909 |
# File 'sig/client.rbs', line 909
def list_portfolio_access: (
|
#list_portfolios(params = {}) ⇒ Types::ListPortfoliosOutput
Lists all portfolios in the catalog.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
924 |
# File 'sig/client.rbs', line 924
def list_portfolios: (
|
#list_portfolios_for_product(params = {}) ⇒ Types::ListPortfoliosForProductOutput
Lists all portfolios that the specified product is associated with.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
937 |
# File 'sig/client.rbs', line 937
def list_portfolios_for_product: (
|
#list_principals_for_portfolio(params = {}) ⇒ Types::ListPrincipalsForPortfolioOutput
Lists all PrincipalARNs and corresponding PrincipalTypes
associated with the specified portfolio.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
951 |
# File 'sig/client.rbs', line 951
def list_principals_for_portfolio: (
|
#list_provisioned_product_plans(params = {}) ⇒ Types::ListProvisionedProductPlansOutput
Lists the plans for the specified provisioned product or all plans to which the user has access.
965 |
# File 'sig/client.rbs', line 965
def list_provisioned_product_plans: (
|
#list_provisioning_artifacts(params = {}) ⇒ Types::ListProvisioningArtifactsOutput
Lists all provisioning artifacts (also known as versions) for the specified product.
983 |
# File 'sig/client.rbs', line 983
def list_provisioning_artifacts: (
|
#list_provisioning_artifacts_for_service_action(params = {}) ⇒ Types::ListProvisioningArtifactsForServiceActionOutput
Lists all provisioning artifacts (also known as versions) for the specified self-service action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
995 |
# File 'sig/client.rbs', line 995
def list_provisioning_artifacts_for_service_action: (
|
#list_record_history(params = {}) ⇒ Types::ListRecordHistoryOutput
Lists the specified requests or all performed requests.
1009 |
# File 'sig/client.rbs', line 1009
def list_record_history: (
|
#list_resources_for_tag_option(params = {}) ⇒ Types::ListResourcesForTagOptionOutput
Lists the resources associated with the specified TagOption.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1030 |
# File 'sig/client.rbs', line 1030
def list_resources_for_tag_option: (
|
#list_service_actions(params = {}) ⇒ Types::ListServiceActionsOutput
Lists all self-service actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1044 |
# File 'sig/client.rbs', line 1044
def list_service_actions: (
|
#list_service_actions_for_provisioning_artifact(params = {}) ⇒ Types::ListServiceActionsForProvisioningArtifactOutput
Returns a paginated list of self-service actions associated with the specified Product ID and Provisioning Artifact ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1057 |
# File 'sig/client.rbs', line 1057
def list_service_actions_for_provisioning_artifact: (
|
#list_stack_instances_for_provisioned_product(params = {}) ⇒ Types::ListStackInstancesForProvisionedProductOutput
Returns summary information about stack instances that are associated
with the specified CFN_STACKSET type provisioned product. You can
filter for stack instances that are associated with a specific Amazon
Web Services account name or Region.
1072 |
# File 'sig/client.rbs', line 1072
def list_stack_instances_for_provisioned_product: (
|
#list_tag_options(params = {}) ⇒ Types::ListTagOptionsOutput
Lists the specified TagOptions or all TagOptions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1086 |
# File 'sig/client.rbs', line 1086
def list_tag_options: (
|
#notify_provision_product_engine_workflow_result(params = {}) ⇒ Struct
Notifies the result of the provisioning engine execution.
1101 |
# File 'sig/client.rbs', line 1101
def notify_provision_product_engine_workflow_result: (
|
#notify_terminate_provisioned_product_engine_workflow_result(params = {}) ⇒ Struct
Notifies the result of the terminate engine execution.
1127 |
# File 'sig/client.rbs', line 1127
def notify_terminate_provisioned_product_engine_workflow_result: (
|
#notify_update_provisioned_product_engine_workflow_result(params = {}) ⇒ Struct
Notifies the result of the update engine execution.
1140 |
# File 'sig/client.rbs', line 1140
def notify_update_provisioned_product_engine_workflow_result: (
|
#provision_product(params = {}) ⇒ Types::ProvisionProductOutput
Provisions the specified product.
A provisioned product is a resourced instance of a product. For example, provisioning a product that's based on an CloudFormation template launches an CloudFormation stack and its underlying resources. You can check the status of this request using DescribeRecord.
If the request contains a tag key with an empty list of values, there's a tag conflict for that key. Don't include conflicted keys as tags, or this will cause the error "Parameter validation failed: Missing required parameter in Tags[N]:Value".
1161 |
# File 'sig/client.rbs', line 1161
def provision_product: (
|
#reject_portfolio_share(params = {}) ⇒ Struct
Rejects an offer to share the specified portfolio.
1199 |
# File 'sig/client.rbs', line 1199
def reject_portfolio_share: (
|
#scan_provisioned_products(params = {}) ⇒ Types::ScanProvisionedProductsOutput
Lists the provisioned products that are available (not terminated).
To use additional filtering, see SearchProvisionedProducts.
1212 |
# File 'sig/client.rbs', line 1212
def scan_provisioned_products: (
|
#search_products(params = {}) ⇒ Types::SearchProductsOutput
Gets information about the products to which the caller has access.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1230 |
# File 'sig/client.rbs', line 1230
def search_products: (
|
#search_products_as_admin(params = {}) ⇒ Types::SearchProductsAsAdminOutput
Gets information about the products for the specified portfolio or all products.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1246 |
# File 'sig/client.rbs', line 1246
def search_products_as_admin: (
|
#search_provisioned_products(params = {}) ⇒ Types::SearchProvisionedProductsOutput
Gets information about the provisioned products that meet the specified criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1265 |
# File 'sig/client.rbs', line 1265
def search_provisioned_products: (
|
#terminate_provisioned_product(params = {}) ⇒ Types::TerminateProvisionedProductOutput
Terminates the specified provisioned product.
This operation does not delete any records associated with the provisioned product.
You can check the status of this request using DescribeRecord.
1284 |
# File 'sig/client.rbs', line 1284
def terminate_provisioned_product: (
|
#update_constraint(params = {}) ⇒ Types::UpdateConstraintOutput
Updates the specified constraint.
1301 |
# File 'sig/client.rbs', line 1301
def update_constraint: (
|
#update_portfolio(params = {}) ⇒ Types::UpdatePortfolioOutput
Updates the specified portfolio.
You cannot update a product that was shared with you.
1315 |
# File 'sig/client.rbs', line 1315
def update_portfolio: (
|
#update_portfolio_share(params = {}) ⇒ Types::UpdatePortfolioShareOutput
Updates the specified portfolio share. You can use this API to enable
or disable TagOptions sharing or Principal sharing for an existing
portfolio share.
The portfolio share cannot be updated if the CreatePortfolioShare
operation is IN_PROGRESS, as the share is not available to recipient
entities. In this case, you must wait for the portfolio share to be
completed.
You must provide the accountId or organization node in the input,
but not both.
If the portfolio is shared to both an external account and an
organization node, and both shares need to be updated, you must invoke
UpdatePortfolioShare separately for each share type.
This API cannot be used for removing the portfolio share. You must use
DeletePortfolioShare API for that action.
PrincipalType as
IAM. With this configuration, the PrincipalARN must already exist
in the recipient account before it can be associated.
1337 |
# File 'sig/client.rbs', line 1337
def update_portfolio_share: (
|
#update_product(params = {}) ⇒ Types::UpdateProductOutput
Updates the specified product.
1356 |
# File 'sig/client.rbs', line 1356
def update_product: (
|
#update_provisioned_product(params = {}) ⇒ Types::UpdateProvisionedProductOutput
Requests updates to the configuration of the specified provisioned product.
If there are tags associated with the object, they cannot be updated or added. Depending on the specific updates requested, this operation can update with no interruption, with some interruption, or replace the provisioned product entirely.
You can check the status of this request using DescribeRecord.
1382 |
# File 'sig/client.rbs', line 1382
def update_provisioned_product: (
|
#update_provisioned_product_properties(params = {}) ⇒ Types::UpdateProvisionedProductPropertiesOutput
Requests updates to the properties of the specified provisioned product.
1426 |
# File 'sig/client.rbs', line 1426
def update_provisioned_product_properties: (
|
#update_provisioning_artifact(params = {}) ⇒ Types::UpdateProvisioningArtifactOutput
Updates the specified provisioning artifact (also known as a version) for the specified product.
You cannot update a provisioning artifact for a product that was shared with you.
1441 |
# File 'sig/client.rbs', line 1441
def update_provisioning_artifact: (
|
#update_service_action(params = {}) ⇒ Types::UpdateServiceActionOutput
Updates a self-service action.
1457 |
# File 'sig/client.rbs', line 1457
def update_service_action: (
|
#update_tag_option(params = {}) ⇒ Types::UpdateTagOptionOutput
Updates the specified TagOption.
1471 |
# File 'sig/client.rbs', line 1471
def update_tag_option: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6386 6387 6388 |
# File 'lib/aws-sdk-servicecatalog/client.rb', line 6386 def waiter_names [] end |