Class: Aws::ServiceCatalog::Types::GetProvisionedProductOutputsInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-servicecatalog/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accept_languageString

The language code.

  • ‘jp` - Japanese

  • ‘zh` - Chinese



2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
# File 'lib/aws-sdk-servicecatalog/types.rb', line 2788

class GetProvisionedProductOutputsInput < Struct.new(
  :accept_language,
  :provisioned_product_id,
  :provisioned_product_name,
  :output_keys,
  :page_size,
  :page_token)
  SENSITIVE = []
  include Aws::Structure
end

#output_keysArray<String>

The list of keys that the API should return with their values. If none are provided, the API will return all outputs of the provisioned product.



2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
# File 'lib/aws-sdk-servicecatalog/types.rb', line 2788

class GetProvisionedProductOutputsInput < Struct.new(
  :accept_language,
  :provisioned_product_id,
  :provisioned_product_name,
  :output_keys,
  :page_size,
  :page_token)
  SENSITIVE = []
  include Aws::Structure
end

#page_sizeInteger

The maximum number of items to return with this call.



2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
# File 'lib/aws-sdk-servicecatalog/types.rb', line 2788

class GetProvisionedProductOutputsInput < Struct.new(
  :accept_language,
  :provisioned_product_id,
  :provisioned_product_name,
  :output_keys,
  :page_size,
  :page_token)
  SENSITIVE = []
  include Aws::Structure
end

#page_tokenString

The page token for the next set of results. To retrieve the first set of results, use null.



2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
# File 'lib/aws-sdk-servicecatalog/types.rb', line 2788

class GetProvisionedProductOutputsInput < Struct.new(
  :accept_language,
  :provisioned_product_id,
  :provisioned_product_name,
  :output_keys,
  :page_size,
  :page_token)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_product_idString

The identifier of the provisioned product that you want the outputs from.



2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
# File 'lib/aws-sdk-servicecatalog/types.rb', line 2788

class GetProvisionedProductOutputsInput < Struct.new(
  :accept_language,
  :provisioned_product_id,
  :provisioned_product_name,
  :output_keys,
  :page_size,
  :page_token)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_product_nameString

The name of the provisioned product that you want the outputs from.



2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
# File 'lib/aws-sdk-servicecatalog/types.rb', line 2788

class GetProvisionedProductOutputsInput < Struct.new(
  :accept_language,
  :provisioned_product_id,
  :provisioned_product_name,
  :output_keys,
  :page_size,
  :page_token)
  SENSITIVE = []
  include Aws::Structure
end