Class: Aws::ServiceCatalog::Types::NotifyUpdateProvisionedProductEngineWorkflowResultInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-servicecatalog/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failure_reasonString

The reason why the update engine execution failed.



4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
# File 'lib/aws-sdk-servicecatalog/types.rb', line 4102

class NotifyUpdateProvisionedProductEngineWorkflowResultInput < Struct.new(
  :workflow_token,
  :record_id,
  :status,
  :failure_reason,
  :outputs,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#idempotency_tokenString

The idempotency token that identifies the update engine execution.

**A suitable default value is auto-generated.** You should normally not need to pass this option.



4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
# File 'lib/aws-sdk-servicecatalog/types.rb', line 4102

class NotifyUpdateProvisionedProductEngineWorkflowResultInput < Struct.new(
  :workflow_token,
  :record_id,
  :status,
  :failure_reason,
  :outputs,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#outputsArray<Types::RecordOutput>

The output of the update engine execution.



4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
# File 'lib/aws-sdk-servicecatalog/types.rb', line 4102

class NotifyUpdateProvisionedProductEngineWorkflowResultInput < Struct.new(
  :workflow_token,
  :record_id,
  :status,
  :failure_reason,
  :outputs,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#record_idString

The identifier of the record.



4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
# File 'lib/aws-sdk-servicecatalog/types.rb', line 4102

class NotifyUpdateProvisionedProductEngineWorkflowResultInput < Struct.new(
  :workflow_token,
  :record_id,
  :status,
  :failure_reason,
  :outputs,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the update engine execution.



4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
# File 'lib/aws-sdk-servicecatalog/types.rb', line 4102

class NotifyUpdateProvisionedProductEngineWorkflowResultInput < Struct.new(
  :workflow_token,
  :record_id,
  :status,
  :failure_reason,
  :outputs,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_tokenString

The encrypted contents of the update engine execution payload that Service Catalog sends after the Terraform product update workflow starts.



4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
# File 'lib/aws-sdk-servicecatalog/types.rb', line 4102

class NotifyUpdateProvisionedProductEngineWorkflowResultInput < Struct.new(
  :workflow_token,
  :record_id,
  :status,
  :failure_reason,
  :outputs,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end